library(shiny)
library(wordcloud2)
library(shinycssloaders)
source("twitter_keys.r")
twitter_token <- create_token(
  app = "quantoid_scrape",
  consumer_key = key,
  consumer_secret = key_secret, 
  access_token = token, 
  access_secret = token_secret)
rm(key, appname, key_secret, token, token_secret)

ui <- fluidPage(
  sidebarPanel(
    actionButton("updateTweets", "Update Tweets"), 
    htmltools::tags$p("Click update to get a new plot")
  ),
  mainPanel(
    wordcloud2Output("wordcloud") %>% withSpinner(color="#4F2683")
  )
)

server <- function(input, output, session) {
  library(rtweet)
  library(tidytext)
  library(dplyr)
  

  
  observeEvent(input$updateTweets, {
    rts <- search_tweets(q = "#rstats", n=1000, include_rts=FALSE)
    output$wordcloud <- renderWordcloud2({
      txts <- do.call("c", rts$hashtags)
      texts <- data.frame(text = txts)
      freqs <- texts %>% 
        unnest_tokens(word, text)  %>% 
        mutate(word = tolower(word)) %>% 
        group_by(word) %>% 
        summarise(freq=n()) %>% 
        anti_join(get_stopwords())
      wordcloud2(freqs)
    })
  })
  
  
  
}

shinyApp(ui, server)